package examples.exceptions;

/**
 * This class illustrates the mechanics of the finally block of a
 * try/catch/finally statement.
 * 
 * @author Grant Braught, revisions by Farhan Siddiqui
 * @author Dickinson College
 * @version Aug 10, 2019
 */
public class FinallyEx {
    
    public static void main(String[] args) {
        System.out.println("finallyWithCaughtException");
        finallyWithCaughtException();
        
        System.out.println();
        System.out.println("finallyWithoutException:");
        finallyWithoutException();
        
        System.out.println();
        System.out.println("finallyWithUncaughtException");
        finallyWithUncaughtException();
    }
    
    /*
     * This method illustrates that the finally clause runs after the
     * try and catch if an exception is caught.
     */
    private static void finallyWithCaughtException() {
        try {
            System.out.println("I'm trying...");
            int val = Integer.parseInt("123x");
            System.out.println("I'm done...");
        }
        catch (NumberFormatException e) {
            System.out.println("Caught an exception...");
        }
        finally {
            System.out.println("Finally, I mean come on!");
        }
    }
    
    /*
     * This method illustrates that the finally clause runs after the 
     * try even if no exception is generated by the code in the try block.
     */
    private static void finallyWithoutException() {
        try {
            System.out.println("I'm trying...");
            int val = Integer.parseInt("123");
            System.out.println("I'm done...");
        }
        catch (NumberFormatException e) {
            System.out.println("Not going to catch this one...");
        }
        finally {
            System.out.println("Finally, its about time!");
        }
    }

    /*
     * This method illustrates that the finally clause is run after the
     * try when an exception is generated even if it is not caught by a 
     * catch clause.
     */
    private static void finallyWithUncaughtException() {
        try {
            System.out.println("I'm trying...");
            int val = Integer.parseInt("123x");
            System.out.println("I'm done...");
        }
        catch (NullPointerException e) {
            System.out.println("Not going to catch this one...");
        }
        finally {
            System.out.println("Finally, I've been waiting!");
        }
    }
}
