package examples.recursion;

/**
 * Solver for the Tower Of Hanoi problem.
 * 
 * @author Grant Braught, revisions by Farhan Siddiqui
 * @author Dickinson College
 * @version Aug 10, 2019
 */
public class TowerOfHanoi2 {

    /**
     * Print out the instructions for solving a Tower of Hanoi puzzle with n
     * disks on the src (source) peg and the goal of transferring them to the dest (destination) peg.
     * 
     * @param n the number of disks.
     * @param src the peg on which the disks start.
     * @param dest the peg to which to move the disks.
     * @param aux the third peg that is neither the source or the destination.
     */
    public static void towerSolver(int n, String src, String dest, String aux) {
        if (n == 1) {
            // Only one disk - so just move it.
            System.out.println("Move disk from " + src + " to " + dest);
        }
        else { // More than one disk so solve recursively.

            // Move n-1 disks from src to aux.
            towerSolver(n - 1, src, aux, dest);

            // Move the last disk from src to dest.
            towerSolver(1, src, dest, aux);

            // Move n-1 disks from aux to dest.
            towerSolver(n - 1, aux, dest, src);
        }
    }
    
    /**
     * Solve an n-disk Tower of Hanoi problem by printing the steps for moving
     * n disks from peg A to peg C.
     */
    public static void towerSolver(int n) {
    	  towerSolver(n, "A", "C", "B");
    }

    /**
     * Solve a 3 disk instance of the Tower of Hanoi problem starting on peg A
     * and ending on peg C.
     */
    public static void main(String[] args) {
        towerSolver(3);
    }
}
